@@ -15,6 +15,7 @@ from typing import Optional, Awaitable, Any
 
 from bson import ObjectId
 from tornado import httputil
+from tornado.escape import utf8
 from tornado.ioloop import IOLoop
 from tornado.web import RequestHandler, Application
 from lesscode.web.status_code import StatusCode
@@ -272,6 +273,23 @@ class BaseHandler(RequestHandler):
                 return user
         return None
 
+    def redirect(self, url: str, permanent: bool = False, status: int = None) -> None:
+        """Sends a redirect to the given (optionally relative) URL.
+
+        If the ``status`` argument is specified, that value is used as the
+        HTTP status code; otherwise either 301 (permanent) or 302
+        (temporary) is chosen based on the ``permanent`` argument.
+        The default is 302 (temporary).
+        """
+        if self._headers_written:
+            raise Exception("Cannot redirect after headers have been written")
+        if status is None:
+            status = 301 if permanent else 302
+        else:
+            assert isinstance(status, int) and 300 <= status <= 399
+        self.set_status(status)
+        self.set_header("Location", utf8(url))
+
     def add_create_info(self, data):
         user: User = self.get_current_user()
         if user:
